A Jupyter/IPython kernel for Octave

This requires IPython 3.

To test it, install via ``pip`` or ``setup.py``, then::

    ipython qtconsole --kernel=octave_kernel

Or select the Octave Kernel in the IPython Notebook.

This is based on `MetaKernel <http://pypi.python.org/pypi/metakernel>`_,
which means it features a standard set of magics.

A sample notebook is available online_.


.. _online: http://nbviewer.ipython.org/github/Calysto/octave_kernel/blob/master/octave_kernel.ipynb